@@ -1,6 +1,7 @@
+;;; -*- lexical-binding: t; -*-
 ;;; eide-search.el --- Emacs-IDE: Search in files (code browsing)
 
-;; Copyright © 2008-2024 Cédric Marie
+;; Copyright © 2008-2025 Cédric Marie
 
 ;; This program is free software: you can redistribute it and/or modify it
 ;; under the terms of the GNU General Public License as published by the Free
@@ -154,7 +155,7 @@ Arguments:
 ;; INTERNAL FUNCTIONS
 ;; ----------------------------------------------------------------------------
 
-(defun eide-i-search-tags-sentinel (p-process p-event)
+(defun eide-i-search-tags-sentinel (_p-process p-event)
   "Sentinel for \"create tags\" process.
 Arguments:
 - p-process: process.
@@ -164,7 +165,7 @@ Arguments:
     (setq eide-search-tags-creation-in-progress-flag nil)
     (message "Creating tags... done")))
 
-(defun eide-i-search-cscope-sentinel (p-process p-event)
+(defun eide-i-search-cscope-sentinel (_p-process p-event)
   "Sentinel for \"create cscope\" process.
 Arguments:
 - p-process: process.
